==> jc-1.4.0.tar.gz: gnu/xml/xpath/XPathParser__24YySindexClass.h <==
// public final class gnu.xml.xpath.XPathParser$YySindexClass

// class file dependencies
// @dep_class bfb1a6e3ae804987 gnu_xml_xpath_XPathParser__24YySindexClass
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YySindexClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YySindexClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$object	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct {
	_jc_short_array	*yySindex;
};
extern _jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YySindexClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$object *);

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YySindexClass$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods	gnu_xml_xpath_XPathParser__24YySindexClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs	gnu_xml_xpath_XPathParser__24YySindexClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YySindexClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype _jc_gnu_xml_xpath_XPathParser__24YySindexClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YySindexClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YySindexClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YySindexClass_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/xpath/XPathParser__24YySindexClass.h <==
// public final class gnu.xml.xpath.XPathParser$YySindexClass

// class file dependencies
// @dep_class bfb1a6e3ae804987 gnu_xml_xpath_XPathParser__24YySindexClass
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_xpath_XPathParser__24YySindexClass_H_
#define _JC_gnu_xml_xpath_XPathParser__24YySindexClass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs;
typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$object	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$object;

typedef struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable;
typedef const struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype;

// Class fields structure
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct {
	_jc_short_array	*yySindex;
};
extern _jc_gnu_xml_xpath_XPathParser__24YySindexClass$fields_struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$class_fields;

// Constructors
extern void _jc_gnu_xml_xpath_XPathParser__24YySindexClass$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_gnu_xml_xpath_XPathParser__24YySindexClass$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods {
};

// Vtable
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vmethods	gnu_xml_xpath_XPathParser__24YySindexClass;
};

// Vtype
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype {
	_jc_type			type;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs {
    _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_refs	gnu_xml_xpath_XPathParser__24YySindexClass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_XPathParser__24YySindexClass$sub_nonrefs	gnu_xml_xpath_XPathParser__24YySindexClass;
};

// Object instance structure
struct _jc_gnu_xml_xpath_XPathParser__24YySindexClass$object {
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype	*vtype;
	_jc_gnu_xml_xpath_XPathParser__24YySindexClass$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_xpath_XPathParser__24YySindexClass$vtype _jc_gnu_xml_xpath_XPathParser__24YySindexClass$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_xpath_XPathParser__24YySindexClass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_xpath_XPathParser__24YySindexClass$class_object;

#endif	/* _JC_gnu_xml_xpath_XPathParser__24YySindexClass_H_ */
